const cmd = require('node-cmd');

let ping = async (id, name, ip, callback_end, callback_update) => {

    let processRef = cmd.run('ping -c 4 ' + ip);

    let step = 0;

    let result_obj = {
        id: id,
        name: name,
        ip: ip,
        success: true,
        packets: [],
        result: {
            packets: {
                transmitted: 0,
                received: 0,
                loss: 0
            },
            time: {
                min: 0,
                avg: 0,
                max:0
            }
        }
    };

    processRef.stdout.on(
        'data',
        (data) => {
            step = step + 1;

            const regex = /.*icmp_seq=(.*?) ttl=(.*?) time=(.*?) .*$/gm; // ping line
            const regex1 = /^(.*?) packets transmitted, (.*?) received, (.*?)%.*time (.*?)ms/gm; // vorletzte line
            const regex2 = /^.*mdev = (.*?)\/(.*?)\/(.*?)\//gm; // letzte line

            let m = regex.exec(data); // data         icmp_seq/ttl/time ms
            let m1 = regex1.exec(data); // vorletzt   packed transmitted/received/loss
            let m2 = regex2.exec(data); // letzte     min/avg/max    ms

            if(
                m !== undefined && m !== null && m.length === 4
            ){
                result_obj.packets.push({
                    icmp_seq: m[1],
                    ttl: m[2],
                    time: m[3]
                });
            }

            if(
                m1 !== undefined && m1 !== null && m1.length === 5
            ){
                result_obj.result.packets.transmitted = m1[1];
                result_obj.result.packets.received = m1[2];
                result_obj.result.packets.loss = m1[3];
            }

            if(
                m2 !== undefined && m2 !== null && m2.length === 4
            ){
                result_obj.result.time.min = m2[1];
                result_obj.result.time.avg = m2[2];
                result_obj.result.time.max = m2[3];
            }

            callback_update(result_obj);
        }
    );

    processRef.stdout.on(
        'close',
        () => {
            callback_end(result_obj);
        }
    );

    processRef.stderr.on(
        'data',
        (data) => {
            callback_end(data);
        }
    );
}
module.exports = ping;
